__version__ = '1.2.2'
__author__ = 'ZephyrOff  (Alexandre Pajak)'
__descriptor__ = 'Générateur de menu à touches fléchées'
__lastupdate__ = '23/12/2022'
__releasenote__ = 'Patch size of menu element'

from .menu import *